\def\fileversion{1.08c}
\def\filedate{2015/08/07}
%06.11.2014 moved articlebox up
%18.04.2015: moved biblatex to biblatex.sty. Added code to load a journal specific biblatex.sty
%28.04.2015 added \journaldoiprefix
%1.08: 01.05.2015 changed definition of articleDOI to handle numbers without prefix %reverted
%07.08.2015 added dot to "et al"

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{template/journal}[\filedate\space Version \fileversion]

\providecommand\jwslistofjournals{example}
\def\jws@example@fontsize{11pt}

% to allow the creation of an online and a print version:
\newif\ifjwsprintmode
\providecommand\jwsoutputmode{\jwsprintmodefalse}
\jwsoutputmode

%with \newjwsjournal new journals shortcuts can be added
%the optional argument sets the font size of the journal:

\newcommand\newjwsjournal[2][11pt]{%
  \g@addto@macro\jwslistofjournals{,#2}%
  \expandafter\def\csname jws@#2@fontsize\endcsname{#1}%
  \expandafter\def\csname jws@#2@biblatexstyle\endcsname{authoryear}%
  }


% add the current journals:
\newjwsjournal{cfr}
\newjwsjournal{dea}
\newjwsjournal{irere}
\newjwsjournal{jlfa}
\newjwsjournal{jmb}
\newjwsjournal[10pt]{jws}%fontsize will be change again in the sty
\newjwsjournal{sbe}
\newjwsjournal{rbe}
\newjwsjournal[10pt]{qjps}
\newjwsjournal[12pt]{jws}

% in this cfg-file new journals can be declared
\InputIfFileExists{jws-listofjournals.cfg}{}{}

%etoolbox is needed to avoid clashes with hyperref.
\IfFileExists{etoolbox.sty}{%
 \RequirePackage{etoolbox}%
 }{}{}

 \ifcsname AfterEndPreamble\endcsname
 \else
 \let\AfterEndPreamble\AtBeginDocument
 \fi

%Some \if for the options:
\newif\if@jwswrapper
\@jwswrapperfalse

\newif\if@jwsnobib
\@jwsnobibfalse

\newif\if@jwsbiber
\@jwsbiberfalse

\newif\if@jwsmicrotype
\@jwsmicrotypefalse

\newif\if@jwsonlineversion
\@jwsonlineversiontrue

%Options
\DeclareOption{wrapper}{\@jwswrappertrue}%
\DeclareOption{nobib}{\@jwsnobibtrue}
\DeclareOption{biber}{\@jwsnobibfalse\@jwsbibertrue}
\DeclareOption{microtype}{\@jwsmicrotypetrue}

%every journal shortcut creates an option:
\@for\jws@temp:=\jwslistofjournals\do
 {\edef\next{\noexpand\DeclareOption{\jws@temp}{\noexpand\def\noexpand\jws@journalkey{\jws@temp}}}%
  \next}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

\ExecuteOptions{example}
\ProcessOptions\relax


%Load class
\RequirePackage{fix-cm}
\LoadClass[\csname jws@\jws@journalkey @fontsize\endcsname,letterpaper,onecolumn,twoside]{article}


%Fonts
%TO-DO: Tests for luatex, xetex ?
\RequirePackage[T1]{fontenc}
\RequirePackage{textcomp}
\RequirePackage{eurosym}
\let\texteuro\euro
\if@jwsmicrotype
\IfFileExists{microtype.sty}
 {\RequirePackage{microtype}}
 {\typeout{microtype not found}}
\fi
%Tools -- packages needed by the class
\RequirePackage{ifthen}
\RequirePackage{lastpage}
\RequirePackage{refcount}
\setrefcountdefault{1}
\RequirePackage{keyval}
\RequirePackage{xr}
\RequirePackage[bottom,multiple]{footmisc}
\RequirePackage{trimspaces}
\RequirePackage{array}
\IfFileExists{needspace.sty}{\RequirePackage{needspace}}{\typeout{needspace not found.}}

%Useful user packages
\IfFileExists
 {csquotes.sty}
 {\RequirePackage{csquotes}}
 {\typeout{csquotes not found. Faking enquote to produce normal quotes}}
\providecommand\enquote[1]{``#1''}

\RequirePackage{graphicx}
\RequirePackage[figuresright]{rotating}
\RequirePackage{dcolumn}
\newcolumntype{d}[1]{D{.}{.}{#1}}

\RequirePackage{amsmath,amsthm}

\IfFileExists
 {booktabs.sty}
 {\RequirePackage{booktabs}}
 {\typeout{booktabs not found}}

%some registers
\newcounter{jws@tempcnt}
\newtoks\jws@temptoks
\newwrite\jws@write
\newlength\jws@templen

%fonts
\newcommand\jws@font@section                 {\normalfont\normalsize\sffamily\bfseries\boldmath}
\newcommand\jws@font@frontmattersection      {\jws@font@section\rmfamily}
\newcommand\jws@font@subsection              {\normalfont\small\bfseries\itshape\boldmath}
\newcommand\jws@font@frontmattersubsection   {\jws@font@subsection\upshape}
\newcommand\jws@font@subsubsection{\normalfont\small\itshape}
\newcommand\jws@font@paragraph    {\normalfont\normalsize\bfseries\boldmath}
\newcommand\jws@font@subparagraph {\normalfont\normalsize\itshape}
\newcommand\jws@font@caption      {\normalfont\footnotesize}
\newcommand\jws@font@table        {\normalfont\footnotesize}
\newcommand\jws@font@articledata  {\normalfont\footnotesize}
\newcommand\jws@font@footer       {\normalfont\small}
\newcommand\jws@font@header       {\normalfont\footnotesize\itshape}
\newcommand\jws@font@abstract     {\normalfont\normalsize}
\newcommand\jws@font@keywordstitle{\normalfont\normalsize\itshape}
\newcommand\jws@font@keywordstext {\normalfont\normalsize}
\newcommand\jws@font@authors      {\normalfont\normalsize}
\newcommand\jws@font@affil        {\normalfont\normalsize\itshape}
\newcommand\jws@font@title        {\normalfont\LARGE\bfseries\selectfont}
\newcommand\jws@font@subtitle     {\normalfont\small\bfseries\selectfont}
\newcommand\jws@font@editortext   {\normalfont\small\selectfont}
\newcommand\jws@font@infotext     {\normalfont\fontsize{9}{12}\selectfont}
\newcommand\jws@font@tablenote    {\normalfont\scriptsize}
\newcommand\jws@font@tablefigdesc {\normalfont\footnotesize}

\DeclareRobustCommand\jws@font@authorcontents{\normalfont\normalsize\itshape}

%Page layout
\normalsize\selectfont
\usepackage[paperwidth=156mm,
            paperheight=234mm,
            hmarginratio=1:1,
            vmarginratio=1:1,
            textwidth=28pc,
            %headheight=8pt,
            headsep=17pt,
            footskip=22pt,
            textheight=180mm,
            heightrounded]{geometry}

\PassOptionsToPackage{x11namees,svgnames,table}{xcolor}
\IfFileExists{xcolor.sty}
 {\RequirePackage{xcolor}}
 {\RequirePackage{color}
  \RequirePackage{colortbl}}


%sectioning
\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-24pt \@plus -6pt \@minus -3pt}%
                                   {12pt}%
                                   {\jws@font@section}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                   {-18pt \@plus -6pt \@minus -3pt}%
                                   {6pt}%
                                    {\jws@font@subsection}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                   {-22pt \@plus -2pt \@minus -2pt}%
                                   {6pt}%
                                    {\jws@font@subsubsection}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                   {-12pt \@plus -2pt \@minus -2pt}%
                                    {.001pt}%
                                    {\jws@font@paragraph}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\z@}%UF changed \parindent to \z@
                                    {3.25ex \@plus1ex \@minus .2ex}%
                                     {-1em}%
                                     {\jws@font@subparagraph}}

%compact itemize in the journaldata
\newcommand\jwscompactlist{%
 \itemsep=0pt \@topsep=0.5\@topsep \parskip=0pt}

%bibliography
\providecommand\jwsbiblatexbackend{biber}
\if@jwsnobib
 \expandafter\@firstoftwo
\else
 \expandafter\@secondoftwo
\fi
  {\providecommand\printbibliography[1][]{}}
  {\if@jwsbiber
    \expandafter\@firstoftwo
   \else
    \expandafter\@secondoftwo
   \fi
   {\RequirePackage{template/biblatex}}
   {\RequirePackage{natbib}
    \bibliographystyle{jwssort}
    \def\jws@addbib@resource{}%
    \def\jws@bibcomma{}
    \def\addbibresource#1{%
     \filename@parse{#1}%
     \ifx\filename@ext\relax
      \PackageWarning{template/journal}{You forgot the extension "bib"}{}
     \else
      \edef\jws@tempa{\jws@bibcomma\filename@area\filename@base}%
      \gdef\jws@bibcomma{,}%
      \expandafter\g@addto@macro\expandafter\jws@addbib@resource\expandafter{\jws@tempa}%
     \fi}
    \newcommand\printbibliography[1][]{%
     \ifx\jws@addbib@resource\@empty
      %\PackageError{template/journal}{No bib-file declared}{}
     \else
      \expandafter\bibliography\expandafter{\jws@addbib@resource}%
     \fi
  }}}



%Data commands

% \jws@setupdatacommands defines command
% of type \xyx{#1} = \def\jws@xyx{#1}
\newcommand\jws@setupdatacommands[1]{%
 \@for\jws@tempcs:=#1\do
  {\expandafter\newcommand\csname jws@\jws@tempcs\endcsname{}%
   \expandafter\def\csname jws@\jws@tempcs\endcsname{}%
   \edef\next{%
   \noexpand\newcommand\csname \jws@tempcs\endcsname[1]{%
   \noexpand\expandafter\noexpand\gdef\noexpand\csname jws@\jws@tempcs\endcsname{####1}}}%
   \next
  }}

%% data set in articles. Naming is rather loose.

%2 types of keywords: JEL and main:
\newcommand\jws@keywords@main{}
\let\jws@keywords@main\@empty
\newcommand\jws@keywords@main@title{Keywords}

\expandafter\newcommand\csname jws@keywords@JEL\endcsname{}
\let\jws@keywords@JEL\@empty
\newcommand\jws@keywords@JEL@title{JEL Codes}

\newlength\jws@len@keywordindent

\newcommand\keywords[2][main]{%
 \ifcsname jws@keywords@#1\endcsname
  \expandafter\def\csname jws@keywords@#1\endcsname{#2}%
  \settowidth\jws@templen{{\jws@font@keywordstitle\csname jws@keywords@#1@title\endcsname:~}}%
  \ifdim\jws@templen>\jws@len@keywordindent
   \jws@len@keywordindent=\jws@templen
  \fi
 \else
  \ClassError{template/journal}{Keyword type #1 unknown}
 \fi}

\newcommand\jws@keyword@sep{,\space}

\newcommand\jws@print@keywords[1]{%
 \unskip
 \def\jws@temp@startpunct{}%
 \@for\jws@temp:=#1 \do{%
  \jws@temp@startpunct{}\jws@temp
  \let\jws@temp@startpunct\jws@keyword@sep
  }}


% title need special treatment as it can be different in various locations (bib, header, toc, title)
\define@key{jwstitle}{bib}{\def\jws@articlebibtitle{#1}}
\define@key{jwstitle}{header}{\def\jws@articleheadertitle{#1}}
\define@key{jwstitle}{title}{\def\jws@articletitle{#1}}
\define@key{jwstitle}{toc}{\def\jws@articletoctitle{#1}}

 \newcommand\jws@articletitle{}
 \newcommand\jws@articlebibtitle{}
 \newcommand\jws@articleheadertitle{}
 \newcommand\jws@articletoctitle{}


\renewcommand\title[2][]{%
 \setkeys{jwstitle}{bib={#2},header={#2},title={#2},toc={#2}}
 \setkeys{jwstitle}{#1}}



% subtitles are not predefined and currently not used. But perhaps need later.

\newcommand\articlesubtitle[1]{\gdef\jws@articlesubtitle{#1}}
\let\subtitle\articlesubtitle

\def\jws@titlefootnote{}
\newcommand\titlefootnote[1]{\def\jws@titlefootnote{#1}}


%authors need very special treatment.
%There three places where author names (lists) are used: title (fullname), header (last), bib-file
%authors can have three name parts: First, Junior, Last (in bib-Order).

\def\jws@splitauthor#1,#2,#3,#4\@nil{%
 \def\jws@tempa{!}%
 \def\jws@firstname{}\def\jws@juniorpart{}\def\jws@lastname{}%
 \def\jws@tempfirstarg{#1}\def\jws@tempsecondarg{#2}\def\jws@tempthirdarg{#3}%
 \ifx\jws@tempthirdarg\jws@tempa
   \ifx\jws@tempsecondarg\jws@tempa
    \typeout{First name missing}%
    \def\jws@lastname{#1}%
   \else
    \def\jws@lastname{#1}%
    \def\jws@firstname{#2}%
   \fi
 \else
   \def\jws@lastname{#1}%
   \def\jws@juniorpart{#2}%
   \def\jws@firstname{#3}%
 \fi%
   \trim@spaces@in\jws@lastname
   \trim@spaces@in\jws@juniorpart
   \trim@spaces@in\jws@firstname}

\newcounter{jws@author@cnt}
\newcounter{jws@affil@cnt}
\newcounter{jws@affilmax@cnt}
\setcounter{jws@affil@cnt}{0}

\newcommand\jws@authorlist@bibsep{}
\newcommand\jws@authorlist@bib{}

\renewcommand\author[2][\the\numexpr\c@jws@affil@cnt+1]{%
 \stepcounter{jws@author@cnt}%
 \jws@splitauthor#2,!,!,\@nil%
 \edef\next{\noexpand\g@addto@macro\noexpand\jws@authorlist@bib{%
        \jws@authorlist@bibsep\unexpanded{#2}}}\next
 \def\jws@authorlist@bibsep{ and }%
 \expandafter\edef\csname jws@authorlastname@\the\c@jws@author@cnt\endcsname{\unexpanded\expandafter{\jws@lastname}}%
 \expandafter\edef\csname jws@authorfullname@\the\c@jws@author@cnt\endcsname%
           {\unexpanded\expandafter{\jws@firstname~}\unexpanded\expandafter{\jws@lastname}%
             \ifx\jws@juniorpart\@empty
             \else,\noexpand~\unexpanded\expandafter{\jws@juniorpart}%
             \fi}%
 \expandafter\edef\csname jws@authoraffilmark@\the\c@jws@author@cnt\endcsname{#1}%
 \jws@store@authorlist@header
 \jws@store@authorlist@toc
}

\newcommand\affil[2][\the\c@jws@affil@cnt]{%
 \stepcounter{jws@affil@cnt}%
 \c@jws@affilmax@cnt=\numexpr\c@jws@author@cnt\relax
 \expandafter\def\csname jws@affil@\the\c@jws@affil@cnt\endcsname{#2}%
 \expandafter\edef\csname jws@affilmark@\the\c@jws@affil@cnt\endcsname{#1}%
 }

%Commands to create authorlists
% 1. a list for the header: Lastnames, if > 2 authors: et al,
\newcommand\jws@authorlist@header{}%
\newcommand\jws@store@authorlist@header{%
 \ifcase\c@jws@author@cnt
 \or
 \edef\jws@authorlist@header{\unexpanded\expandafter\expandafter\expandafter{\csname jws@authorlastname@1\endcsname}}%
 \or
 \edef\jws@authorlist@header{\unexpanded\expandafter\expandafter\expandafter{\csname jws@authorlastname@1\endcsname} and
                             \unexpanded\expandafter\expandafter\expandafter{\csname jws@authorlastname@2\endcsname}}%
 \else
 \edef\jws@authorlist@header{\unexpanded\expandafter\expandafter\expandafter{\csname jws@authorlastname@1\endcsname} et al.}%
 \fi}%

% 1. a list for the wrapper  toc.
\newcommand*\jws@authorlist@toc{}

\newcommand\jws@store@authorlist@toc{%
  \edef\jws@authorlist@toc{\unexpanded\expandafter\expandafter\expandafter{\csname jws@authorfullname@1\endcsname}}%
  \ifnum\c@jws@author@cnt=1\relax
  \else
  \c@jws@tempcnt=2\relax
    \whiledo{\c@jws@tempcnt<\c@jws@author@cnt}
      {\edef\jws@authorlist@toc%
         {\unexpanded\expandafter{\jws@authorlist@toc,}
          \unexpanded\expandafter\expandafter\expandafter{\csname jws@authorfullname@\the\c@jws@tempcnt\endcsname}}%
       \stepcounter{jws@tempcnt}%
      }%
      \edef\jws@authorlist@toc%
       {\unexpanded\expandafter{\jws@authorlist@toc} and
        \unexpanded\expandafter\expandafter\expandafter{\csname jws@authorfullname@\the\c@jws@author@cnt\endcsname}}%
  \fi
}


\define@key{jwsauthorlist}{bib}{\def\jws@authorlist@bib{#1}}
\define@key{jwsauthorlist}{header}{\def\jws@authorlist@header{#1}}
\define@key{jwsauthorlist}{toc}{\def\jws@authorlist@toc{#1}}
\newcommand\authorlists[1]{\setkeys{jwsauthorlist}{#1}}


%Data per issues. Name starts always with issue

 \jws@setupdatacommands{issuecopyrightyear,%
                        issuevolumenumber,%
                        issuevolumeyear,%
                        issuestartpage,%
                        issuenumber}

\issuecopyrightyear{2022}
\issuevolumenumber{8}
\issuenumber{X}
\issuevolumeyear{2022}
\issuestartpage{1}

%Data per journal. Name starts with journal.
 \jws@setupdatacommands{journaltitle,%
                        journalshorttitle,%
                        journalurl,%
                        journalissnprint,%
                        journalissnonline,%
                        journalaimsandscope,%
                        journalsubmission,%
                        journalabstractedin,%
                        journaltotalissuenumber,%
                        journaldoiprefix,%
                        }

\journaltotalissuenumber{4}

\newcommand\journalname{\jws@journaltitle}
\newcommand\journalshortname{\jws@journalshorttitle}

%Input the data. The issuedata is generated by the wrapper. It will, if necessary overwrite the journalkey
\if@jwswrapper
\else
 \InputIfFileExists{../current-issuedata}{}{}%
\fi
%Search first the wrapper folder, then the texmf+current dir.
 \IfFileExists{../journaldata.tex}
  {\input{../journaldata.tex}}
  {\IfFileExists{journaldata.tex}
   {\input{journaldata}}
   {\typeout{Journal data for JWS not found}
    \typeout{loading the example data instead}%
    \input{template/journaldata}}}

%write the data to a bib-file + a toc-file
\newcommand\jwstocnewline{}
\if@jwswrapper\else
\AtEndDocument{%
 \immediate\openout\jws@write =\jobname-bibinfo.bib\relax
 \immediate\write\jws@write{@article\csname @charlb\endcsname \jobname,}
 \immediate\write\jws@write{title={\unexpanded\expandafter\expandafter\expandafter{\jws@articlebibtitle}},}
 \ifcsname jws@articlesubtitle\endcsname
 \immediate\write\jws@write{subtitle={\csname jws@articlesubtitle\endcsname},}
 \fi
 \immediate\write\jws@write{author={\unexpanded\expandafter{\jws@authorlist@bib}},}
 \immediate\write\jws@write{journaltitle={\csname jws@journaltitle\endcsname},}
 \immediate\write\jws@write{year={\jws@issuevolumeyear},}%
 \immediate\write\jws@write{pages= {\getpagerefnumber{FirstPage}-\getpagerefnumber{LastPage}},}
 \ifx\jws@journalissnprint\@empty
 \immediate\write\jws@write{issn={\csname jws@journalissnonline\endcsname},}
 \else
 \immediate\write\jws@write{issn={\csname jws@journalissnprint\endcsname},}
 \fi
 \ifx\jws@articleDOI\jws@defaulttextcontent\else
  \immediate\write\jws@write{DOI={\jws@articleDOI},}
 \fi
 \ifx\jws@keywords@main\@empty\else
 \immediate\write\jws@write{JWSkeywords={\jws@keywords@main},}
 \fi
 \ifx\jws@keywords@JEL\@empty\else
 \immediate\write\jws@write{JELkeywords={\jws@keywords@JEL}}
 \fi
 \immediate\write\jws@write{\csname @charrb\endcsname}%
 \immediate\closeout\jws@write
 \immediate\openout\jws@write=\jobname-wrapper.toc\relax
 \ifx\jws@authorlist@toc\@empty
  \immediate\write\jws@write{%
  \noexpand\addtocontents{toc}{%
  \noexpand\protect\noexpand\contentsline{section}{%
   \unexpanded\expandafter{\jws@articletoctitle}}%
  {\getpagerefnumber{FirstPage}--\getpagerefnumber{LastPage}}{}}}%
 \else
 \immediate\write\jws@write{%
  \noexpand\addtocontents{toc}{%
  \noexpand\protect\noexpand\contentsline{section}{%
   \unexpanded\expandafter{\jws@articletoctitle\jwstocnewline}{\unexpanded{\csname jws@font@authorcontents\endcsname}\unexpanded\expandafter{\jws@authorlist@toc}}}
  {\getpagerefnumber{FirstPage}--\getpagerefnumber{LastPage}}{}}}%
 \fi
 \immediate\closeout\jws@write
 }
\fi


%get + set pagenumber
\@ifundefined{jwspredecessor}
 {\setcounter{page}{\jws@issuestartpage}}
 {\externaldocument[page-]{\jwspredecessor}%
  \setcounter{page}{\getpagerefnumber{page-LastPage}}%
  \stepcounter{page}%
  \ifodd\c@page\else\stepcounter{page}\fi}

\AfterEndPreamble{\label{FirstPage}}

%footnotes
\renewcommand\footnoterule{%
  \kern-3\p@
  \hrule\@width\columnwidth
  \kern2.6\p@}


%abstract
\newcommand\jws@abtractendhook{}

\renewenvironment{abstract}
 {\jws@font@abstract\clubpenalty=10000%
  \begin{list}{}{\rightmargin\leftmargin}%
          \item\relax
 \hspace*{-\leftmargin}\noindent\makebox[\linewidth][l]{\rule{\textwidth}{0.5pt}}\par\vspace{\medskipamount}\nobreak
          ABSTRACT\par\@afterheading}
 {\par\nobreak\hspace*{-\leftmargin}\makebox[\linewidth][l]{\rule{\textwidth}{0.5pt}}\end{list}
  \ifx\jws@keywords@main\@empty
  \else
  \begingroup\jws@font@keywordstext\noindent
    \@hangfrom{\makebox[\jws@len@keywordindent][l]{\jws@font@keywordstitle\jws@keywords@main@title:~}}%
    \jws@print@keywords{\jws@keywords@main}\par\endgroup
  \addvspace{\medskipamount}%
  \fi
  \ifx\jws@keywords@JEL\@empty
  \else
  \begingroup\jws@font@keywordstext\noindent
   \@hangfrom{\makebox[\jws@len@keywordindent][l]{\jws@font@keywordstitle\jws@keywords@JEL@title:~}}\jws@print@keywords{\jws@keywords@JEL}\par\endgroup
  \fi
  \addvspace{\medskipamount}\jws@abtractendhook}

%maketitle
\newcommand\jws@printaffilmark[1]{%#1=author number
  \textsuperscript{\csname jws@authoraffilmark@#1\endcsname}%
 }



\DeclareRobustCommand\jws@printauthors{%
 \ifnum\c@jws@author@cnt=0\relax
 \else
   \csname jws@authorfullname@1\endcsname
      \jws@printaffilmark{1}%
   \ifnum\c@jws@author@cnt=1\relax
   \else
   \c@jws@tempcnt=2\relax
    \whiledo{\c@jws@tempcnt<\c@jws@author@cnt}
      {,\space\csname jws@authorfullname@\the\c@jws@tempcnt\endcsname
       \jws@printaffilmark{\the\c@jws@tempcnt}%
       \stepcounter{jws@tempcnt}%
      }
    and \csname jws@authorfullname@\the\c@jws@author@cnt\endcsname
        \jws@printaffilmark{\the\c@jws@author@cnt}%
   \fi
   \ifcsname jws@creditlinetext\endcsname
     \footnote{\jws@creditlinetext}%
   \fi
\fi}



\newcommand\jws@printaffils{%
 \begingroup\jws@font@affil
  \ifnum\c@jws@affil@cnt > 0
  \c@jws@tempcnt=0\relax
    \whiledo{\c@jws@tempcnt<\c@jws@affil@cnt}
      {\par
       \stepcounter{jws@tempcnt}%
        \textsuperscript{\upshape\csname jws@affilmark@\the\c@jws@tempcnt\endcsname}%
        \csname jws@affil@\the\c@jws@tempcnt\endcsname
      }%
  \fi
 \endgroup
  }


\newcommand\creditline[2][*]{%
 \def\jws@creditlinemark{#1}%
 \def\jws@creditlinetext{#2}}

\newsavebox\jws@article@databox{}
\sbox\jws@article@databox{}
\newcommand\jws@article@databox@wd{\dimexpr\textwidth\relax}
\newcommand\articledatabox[1]{%
 \AtBeginDocument{%
 \sbox\jws@article@databox{\parbox[b]{\jws@article@databox@wd}
  {\jws@font@articledata\rule{\jws@article@databox@wd}{0.5pt}\par #1}}}}

\newcommand\jws@defaulttextcontent{XXXXXXXX}

\newcommand\articleDOI[1]{\def\jws@articleDOI{#1}}

%\renewcommand\articleDOI[1]{%
% \jws@split@DOI#1//\@nil}

\newcommand\jws@split@DOI{}
\def\jws@split@DOI#1/#2/#3\@nil{%call as \jws@split@DOI<arg>//\@nil
 \def\@tempa{#3}%
 \ifx\@tempa\@empty %kein slash im Argument
   \ifx\jws@journaldoiprefix\@empty
    \ClassWarning{template/journal}{Journal DOI prefix missing!}%
    \def\jws@articleDOI{XX.XXX/#1}%
   \else
    \def\jws@articleDOI{\jws@journaldoiprefix/#1}%
   \fi
 \else
  \def\jws@articleDOI{#1/#2}%
 \fi}


\let\jws@articleDOI\jws@defaulttextcontent

\newcommand\articlecopyrightholder[1]{\def\jws@articlecopyrightholder{#1}}
\let\jws@articlecopyrightholder\jws@defaulttextcontent

\AtBeginDocument{%
\sbox\jws@article@databox{\parbox[b]{\jws@article@databox@wd}
  {\jws@font@articledata\rule{\jws@article@databox@wd}{0.5pt}\par
   ISSN \ifx\jws@journalissnprint\@empty \jws@journalissnonline\else\jws@journalissnprint\fi; DOI \jws@articleDOI\\
   \copyright\jws@issuecopyrightyear~\jws@articlecopyrightholder}}}


\newcommand\disclaimer[1]{\def\jws@disclaimer{#1}}

\renewcommand\maketitle{%
 \begingroup
 \setfnsymbol{wiley}%
 \renewcommand\thefootnote{\fnsymbol{footnote}}%
 \begingroup
 \raggedright
 \thispagestyle{firstpage}%
 \enlargethispage{\dimexpr-\ht\jws@article@databox-\footskip+\baselineskip}%06.11.2014
 \jws@font@title{%
  \def\footnote{\ClassError{template/journal.cls}{Don't use \string\footnote\space in the title!^^J
                Use \string\titlefootnote\space after \string\title\space instead}{}{}}\jws@articletitle}%
 \ifx\jws@titlefootnote\@empty\else\footnote{\jws@titlefootnote}\fi\par\medskip
 \jws@font@authors\jws@printauthors\par\medskip
 \jws@printaffils\par
 \endgroup
 \ifcsname jws@disclaimer\endcsname\medskip\begingroup\noindent\small\textbf{Disclaimer:~}\ignorespaces\jws@disclaimer\par\endgroup\fi
 \endgroup\setcounter{footnote}{0}
 }

\providecommand\jwssetfootnotespace{}
\newdimen\jws@dim@footinsheight
\jws@dim@footinsheight=\the\dimen\footins

\IfFileExists{atbegshi.sty}{%
 \RequirePackage{atbegshi}
 \renewcommand\jwssetfootnotespace[1]{%
  \begingroup\footnotesize
  \global\dimen\footins=##1\baselineskip\relax
  \endgroup
  \AtBeginShipout{\global\dimen\footins =\jws@dim@footinsheight}%
  }}
  {\renewcommand\jwssetfootnotespace[1]{\PackageWarning{template/journal}{atbegshi not found, footnote space can not be changed}{}{}}}{}


%header and footer.

\RequirePackage{fancyhdr}
\pagestyle{fancy}
\renewcommand\headrulewidth{0pt}
\fancyhf{}
\fancyhead[LE,RO]{\jws@font@header\thepage}
\fancyhead[LO]{\jws@font@header\jws@articleheadertitle}
\fancyhead[RE]{\jws@font@header\jws@authorlist@header}

\fancypagestyle{firstpage}{%
 \fancyhf{}%
 \lhead{\jws@font@header\textit{\jws@journaltitle}, \jws@issuevolumeyear, \jws@issuevolumenumber: \pageref{FirstPage}--\pageref{LastPage}}
 \lfoot{\raisebox{\footskip}[0pt][0pt]{\usebox\jws@article@databox}}}%06.11.2014

%load wrapper sty:

\if@jwswrapper
 \IfFileExists{wrapper.sty}
 {\RequirePackage{wrapper}}
 {\ClassError{template/journal}{wrapper.sty not found}{}}
\else
 \AtBeginDocument{%
  \RequirePackage[%
   colorlinks    = true,
   allcolors     = blue,
   plainpages    = false,
   pdfpagelabels = true,
   pdfauthor={\jws@authorlist@toc},
  ]{hyperref}
  \ifjwsprintmode
   \expandafter\@firstofone
  \fi
  {\hypersetup{hidelinks}}%\fi
  }
 \AfterEndPreamble{\maketitle}
\fi

%captions
\IfFileExists{caption.sty}
 {\RequirePackage{caption}
  \DeclareCaptionFont{jws}{\jws@font@caption}
  \captionsetup[table]{position=above}
  \captionsetup{font=jws}
 }
 {\ClassWarning{template/journal}{Couldn't load caption.sty, captions are not set up}{}{}}


%theorem-environments: copied from qjps.cls
\newtheorem{theorem}{Theorem}
\newtheorem{corollary}{Corollary}
\newtheorem{assumption}{Assumption}
\newtheorem{definition}{Definition}
\newtheorem{proposition}{Proposition}
\newtheorem{lemma}{Lemma}
\newtheorem{conjecture}{Conjecture}


\providecommand\Note[1]{\begingroup\par\smallskip\jws@font@tablenote\textbf{Note: }#1\par\endgroup}
\providecommand\Source[1]{}
\providecommand\Description[1]{}
\providecommand\Interpretation[1]{}


% jws.sty
\RequirePackage{etoolbox}
\RequirePackage{environ}

%make sure that current definitions of environ are used:
\def\NewEnviron{%
\let\env@newenvironment\newenvironment
\env@NewEnviron}
\def\RenewEnviron{%
\let\env@newenvironment\renewenvironment
\env@NewEnviron}
\def\env@NewEnviron#1{%
\@ifnextchar[
{\env@new@i{#1}}
{\env@new@iii{#1}{}}}
\def\env@new@i#1[#2]{%
\@ifnextchar[
{\env@new@ii{#1}[#2]}
{\env@new@iii{#1}{[#2]}}}
\def\env@new@ii#1[#2][#3]{%
\env@new@iii{#1}{[#2][#3]}}
\long\def\env@new@iii#1#2#3{%
\@temptokena={\env@new{#1}{#2}{#3}}%
\@ifnextchar[{%
\the\@temptokena
}{%
\expandafter\the\expandafter
\@temptokena\expandafter[\env@finalcode]%
}}
\long\def\env@new#1#2#3[#4]{%
\longdef@c{env@#1@BODY\expandafter}\expandafter{\env@BODY}%
\env@newenvironment{#1}{%
\expandafter\Collect@Body\csname env@#1@parse\endcsname
}{#4}%
\longdef@c{env@#1@parse}##1{%
\csname env@#1@save@env\endcsname##1\env@nil
\csname env@#1@process\endcsname##1\env@nil}%
\expandafter\let\csname env@#1@save@env\endcsname\relax
\expandafter\let\csname env@#1@process\endcsname\relax
\expandafter\newcommand
\csname env@#1@save@env\endcsname#2{%
\expandafter\expandafter\expandafter
\env@save\csname env@#1@BODY\endcsname}%
\expandafter\newcommand
\csname env@#1@process\endcsname#2{#3\env@ignore}%
}
\long\def\env@save#1#2\env@nil{%
\edef#1{%
\unexpanded\expandafter
\expandafter\expandafter{\trim@spaces{#2}}}}
\long\def\env@ignore#1\env@nil{}


\RequirePackage{flushend}
\newgeometry{hmargin=1.3cm,top=25mm,bottom=16mm}

\renewcommand\jws@font@authors      {\normalfont\large}
\renewcommand\jws@font@caption{\fontsize{9pt}{11pt}\selectfont}
\captionsetup{font=jws}
\renewcommand\jws@font@tablenote{\fontsize{9pt}{11pt}\selectfont}



\renewcommand\normalsize{%
\@setfontsize \normalsize {9.5pt}{11.39996pt}%
\abovedisplayskip 9.49956pt plus 1.90039pt minus 5.69998pt
\abovedisplayshortskip 0.0pt plus 2.84999pt
\belowdisplayskip 9.49956pt plus 1.90039pt minus 5.69998pt
\belowdisplayshortskip 5.69998pt plus 2.84999pt minus 2.84999pt
\let\@listi\@listI}

\renewcommand\small{%
\@setfontsize \small {8.66881pt}{10.40254pt}%
\abovedisplayskip 8.66841pt plus 1.73412pt minus 5.20126pt
\abovedisplayshortskip 0.0pt plus 2.60063pt
\belowdisplayskip 8.66841pt plus 1.73412pt minus 5.20126pt
\belowdisplayshortskip 5.20126pt  plus 2.60063pt minus 2.60063pt
\def\@listi{\leftmargin\leftmargini
\topsep 4\p@ \@plus2\p@ \@minus2\p@
\parsep 2\p@ \@plus\p@ \@minus\p@
\itemsep \parsep}}%

\renewcommand\footnotesize{%
\@setfontsize \footnotesize {7.91676pt}{9.50009pt}%
\abovedisplayskip 7.9164pt plus 1.58368pt minus 4.75005pt
\abovedisplayshortskip 0.0pt plus 2.37502pt
\belowdisplayskip 7.9164pt plus 1.58368pt minus 4.75005pt
\belowdisplayshortskip 4.75005pt plus 2.37502pt minus 2.37502pt
\def\@listi{\leftmargin\leftmargini
\topsep 3\p@ \@plus\p@ \@minus\p@
\parsep 2\p@ \@plus\p@ \@minus\p@
\itemsep \parsep}}

\renewcommand\scriptsize{%
\@setfontsize \scriptsize {6.33337pt}{7.60002pt}}

\renewcommand\tiny{%
\@setfontsize \tiny {4.75pt}{5.69998pt}}

\renewcommand\large{%
\@setfontsize \large {11.39996pt}{13.67992pt}}


\renewcommand\Large{%
\@setfontsize \Large {13.68002pt}{16.41599pt}}

\renewcommand\LARGE{%
\@setfontsize \LARGE {16.41597pt}{19.69911pt}}

\renewcommand\huge{%
\@setfontsize \huge {19.70305pt}{23.64359pt}}

\renewcommand\Huge{%
\@setfontsize \Huge {23.63606pt}{28.36319pt}}


\setlength\smallskipamount{3.0pt plus 1.0pt minus 1.0pt}

\setlength\medskipamount{6.0pt plus 2.0pt minus 2.0pt}

\setlength\bigskipamount{12.0pt plus 4.0pt minus 4.0pt}


\fancyhfoffset[E,O]{0pt}

\renewcommand\jwssetfootnotespace[1]{}

\renewcommand\creditline[2][*]{%
\def\jws@jwscreditlinemark{#1}%
\def\jws@jwscreditlinetext{#2}}


\newcommand\jws@print@jwsbiography{%
\ifcsname jws@jwsbiographytext\endcsname
\begingroup
\par\medskip
\def\name##1{\par\medskip\noindent\textbf{##1}\quad\ignorespaces}%
\jws@jwsbiographytext
\par
\endgroup
\fi}

%\providecommand\jws@print@creditline{}
\newcommand\jws@print@jwscreditline{%
\ifcsname jws@jwscreditlinetext\endcsname
\section*{Acknowledgments}
\jws@jwscreditlinetext
\fi}

\ifbool{@jwsnobib}
{\AtBeginEnvironment{thebibliography}{\jws@print@jwsbiography\global\let\jws@jwsbiographytext\@empty}%
\gpreto\@enddocumenthook{%
\jws@print@jwscreditline
\jws@print@jwsbiography}}
{\gpreto\@enddocumenthook{%
\jws@print@jwscreditline
\printbibliography
\jws@print@jwsbiography
}
}

\newcommand\jws@jwsarticledatatext{}
\renewcommand\articledatabox[1]{%
\def\jws@jwsarticledatatext{#1}}

\fancypagestyle{firstpage}{%
\fancyhf{}%
\lhead{\jws@font@header\textit{\jws@journaltitle}, \jws@issuevolumeyear, \jws@issuevolumenumber: \pageref{FirstPage}--\pageref{LastPage}}
\lfoot{}}%06.11.2014


\let\maketitle\relax %suppress the normal title

\newcommand\jws@maketitle{%
\begingroup
\setfnsymbol{wiley}%
\renewcommand\thefootnote{\fnsymbol{footnote}}%
\raggedright
\thispagestyle{firstpage}%
%\enlargethispage{\dimexpr-\ht\jws@article@databox+\baselineskip}%
\twocolumn[{\centering\jws@font@title\jws@articletitle
\ifx\jws@titlefootnote\@empty\else\footnote{\jws@titlefootnote}\fi\par}\medskip
\begin{list}{}{\rightmargin\leftmargin}%
\item\relax
{\centering \jws@font@authors\jws@printauthors\par\medskip}
\jws@printaffils\par
\ifcsname jws@disclaimer\endcsname\medskip\begingroup\small\textbf{Disclaimer:~}\ignorespaces\jws@disclaimer\par\endgroup\fi
\vspace*{\bigskipamount}
\jws@jws@print@abstract
\jws@jws@print@keywords
\end{list}]%
\endgroup
%\enlargethispage{\dimexpr-\ht\jws@article@databox+\baselineskip}
\setcounter{footnote}{0}}


\newtoks\jws@abstracttoks
\RenewEnviron{abstract}{%
\global\jws@abstracttoks\expandafter{\BODY}
\immediate\openout\jws@write=\jobname-abstract.tex
\immediate\write\jws@write{\the\jws@abstracttoks}
\immediate\closeout\jws@write}

\newcommand\jws@jws@print@abstract
{\IfFileExists{\jobname-abstract.tex}%
{\begingroup
\jws@font@abstract\clubpenalty=10000%
ABSTRACT\par\@afterheading
\input{\jobname-abstract}\par
\vspace{\medskipamount}%
\endgroup}{}}%

\newcommand\jws@jws@print@keywords{%
\ifx\jws@keywords@main\@empty
\else
\begingroup\jws@font@keywordstext\noindent
\@hangfrom{\makebox[\jws@len@keywordindent][l]{\jws@font@keywordstitle\jws@keywords@main@title:~}}%
\jws@print@keywords{\jws@keywords@main}\par
\endgroup
\vspace{\medskipamount}%
\fi
\ifx\jws@keywords@JEL\@empty
\else
\vspace{-0.5\medskipamount}%
\begingroup\jws@font@keywordstext\noindent
\@hangfrom{\makebox[\jws@len@keywordindent][l]{\jws@font@keywordstitle\jws@keywords@JEL@title:~}}\jws@print@keywords{\jws@keywords@JEL}%
\par
\endgroup
\vspace{\medskipamount}%
\fi
\ifx\jws@jwsarticledatatext\@empty
\else
\vspace{-0.5\medskipamount}%
\begingroup\jws@font@articledata\noindent
\jws@jwsarticledatatext\par
\endgroup
\vspace{\medskipamount}%
\fi}


\renewcommand\jws@article@databox@wd{\dimexpr0.5\textwidth-0.5\columnsep\relax}

\if@jwswrapper\else
\AfterEndPreamble{\jws@maketitle}
\fi


\newcommand\biography[1]{%
\def\jws@jwsbiographytext{#1}}


\jwssetfootnotespace{3}
\endinput
